@@ -178,7 +178,7 @@ void Kopete::CommandHandler::registerCommand( QObject *parent, const QString &co
 	const QString lowerCommand = command.toLower();
 
 	Kopete::Command *mCommand = new Kopete::Command( parent, lowerCommand, handlerSlot, help,
-		Normal, QString::null, minArgs, maxArgs, cut, pix);	//krazy:exclude=nullstrassign for old broken gcc
+		Normal, QString(), minArgs, maxArgs, cut, pix);
 	p->pluginCommands[ parent ].insert( lowerCommand, mCommand );
 }
 
